"""core URL Configuration

The `urlpatterns` list routes URLs to views. For more information please see:
    https://docs.djangoproject.com/en/3.2/topics/http/urls/
Examples:
Function views
    1. Add an import:  from my_app import views
    2. Add a URL to urlpatterns:  path('', views.home, name='home')
Class-based views
    1. Add an import:  from other_app.views import Home
    2. Add a URL to urlpatterns:  path('', Home.as_view(), name='home')
Including another URLconf
    1. Import the include() function: from django.urls import include, path
    2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
"""
from django.conf import settings
from django.conf.urls.static import static
from django.contrib import admin
from django.urls import path
from web import views

urlpatterns = [
    path('admin/', admin.site.urls),
    path('', views.MainPageRedirectView.as_view()),

    path('articles/', views.ArticleIndexView.as_view(), name='main_page'),
    path('articles/add/', views.ArticleCreateView.as_view(), name='articles-add'),
    path('articles/<int:id>/', views.ArticleDetailView.as_view(), name='articles-detail'),
    path('articles/<int:id>/edit', views.ArticleUpdateView.as_view(), name='article_update'),
    path('articles/<int:id>/delete', views.ArticleDeleteView.as_view(), name='delete_article'),

    path(
        'comments/add/',
        views.CommentCreateView.as_view(),
        name='comment_create'
    ),
    path(
        'comments/<int:id>/edit',
        views.CommentUpdateView.as_view(),
        name='comment_update'
    ),
    path(
        'comments/<int:id>/delete',
        views.CommentDeleteView.as_view(),
        name='comment_delete'
    )
] + static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
